AntCollapsePanelHeaderStyle class

Inheritance

Properties

context BuildContext
final
disabled Style?
finalinherited
dragged Style?
finalinherited
error Style?
finalinherited
focused Style?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hovered Style?
finalinherited
pressed Style?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrolledUnder Style?
finalinherited
selected Style?
finalinherited
style Style
no setteroverride

Methods

merge(StateStyle? source) StateStyle
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(Set<WidgetState> states) Style?
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited