AntSelect class

@component AntSelect 列表选择器

Inheritance

Constructors

AntSelect({Key? key, Widget? cellLabel, String? cellLabelText, AntSelectMode? mode, AntSelectPickerMode pickerMode = AntSelectPickerMode.popup, bool showSearch = false, PreferredSizeWidget? appBar, String? title, String? placeholder, bool arrow = false, AntFieldsNames? fieldsNames, List options = const [], ValueChanged? onSearch, AntSelectValueChanged? onChange, String? searchPlaceholder, dynamic value, dynamic valueOption, AntSelectOptionBuilder? optionBuilder, AsyncCallback? onRefresh, AsyncCallback? onScrollToLower, ValueChanged<bool>? onOpenChange})
const

Properties

appBar PreferredSizeWidget?
@description 顶部栏 @default null
final
arrow bool
@description 是否显示箭头 @default false
final
cellLabel Widget?
final
cellLabelText String?
@description 显示的标签 @default null
final
fieldsNames AntFieldsNames?
@description 字段名 @default AntFieldsNames(label: NamePath("label"),value: NamePath("value"))
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mode AntSelectMode?
@description 选择模式(是否可以多选) @default null
final
onChange AntSelectValueChanged?
@description 值改变回调 @default null
final
onOpenChange ValueChanged<bool>?
@description 打开状态改变回调 @default null
final
onRefresh AsyncCallback?
@description 刷新事件 @default null
final
onScrollToLower AsyncCallback?
@description 滚动到底部事件 @default null
final
onSearch ValueChanged?
@description 搜索框回调 @default null
final
optionBuilder AntSelectOptionBuilder?
@description 选项构建器 @default null
final
options List
@description 选项数据源 @default []
final
pickerMode AntSelectPickerMode
@description 选择器模式 @default AntSelectPickerMode.popup
final
placeholder String?
@description 占位符 @default null
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchPlaceholder String?
@description 搜索框占位符 @default null
final
showSearch bool
@description 是否显示搜索框 @default false
final
title String?
@description 标题 @default null
final
value → dynamic
@description 值 @default null
final
valueOption → dynamic
@description 值选项 @default null
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited