AntTabsState class

Inheritance
Mixed-in types

Constructors

AntTabsState()

Properties

context BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isDisabled bool
Getter for whether this class considers WidgetState.disabled to be active.
no setterinherited
isDragged bool
Getter for whether this class considers WidgetState.dragged to be active.
no setterinherited
isErrored bool
Getter for whether this class considers WidgetState.error to be active.
no setterinherited
isFocused bool
Getter for whether this class considers WidgetState.focused to be active.
no setterinherited
isHovered bool
Getter for whether this class considers WidgetState.hovered to be active.
no setterinherited
isPressed bool
Getter for whether this class considers WidgetState.pressed to be active.
no setterinherited
isScrolledUnder bool
Getter for whether this class considers WidgetState.scrolledUnder to be active.
no setterinherited
isSelected bool
Getter for whether this class considers WidgetState.selected to be active.
no setterinherited
materialStates Set<WidgetState>
Managed set of active WidgetState values; designed to be passed to WidgetStateProperty.resolve methods.
getter/setter pairinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget AntTabs
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
addMaterialState(WidgetState state) → void
Mutator to mark a WidgetState value as active.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant AntTabs oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
getIndex(String? tabKey) int
getStateIndex(AntTabState state) int
init() → void
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
removeMaterialState(WidgetState state) → void
Mutator to mark a WidgetState value as inactive.
inherited
setMaterialState(WidgetState state, bool isSet) → void
Mutator to mark a WidgetState value as either active or inactive.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateMaterialState(WidgetState key, {ValueChanged<bool>? onChanged}) ValueChanged<bool>
Callback factory which accepts a WidgetState value and returns a closure to mutate materialStates and call setState.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited