StateStyle class

Implementers

Constructors

StateStyle({Style? style, Style? hovered, Style? focused, Style? pressed, Style? dragged, Style? selected, Style? scrolledUnder, Style? disabled, Style? error})
const

Properties

disabled Style?
final
dragged Style?
final
error Style?
final
focused Style?
final
hashCode int
The hash code for this object.
no setterinherited
hovered Style?
final
pressed Style?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrolledUnder Style?
final
selected Style?
final
style Style?
final

Methods

merge(StateStyle? source) StateStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(Set<WidgetState> states) Style?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited