WidgetUtils class

Constructors

WidgetUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

iconMerge(Icon target, Icon source) Icon
join(List<Widget> widgets, Widget separator) List<Widget>
textMerge(Text target, Text? source) Text